@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -23,7 +23,7 @@
 #include "common/mm_multi_file_io.h"
 #include "common/mpeg1_2.h"
 #include "merge/packet_extensions.h"
-#include "merge/pr_generic.h"
+#include "merge/generic_reader.h"
 
 struct mpeg_ps_id_t {
   int id;
@@ -122,7 +122,7 @@ struct mpeg_ps_track_t {
   int raw_seq_hdr_size;
 
   int a_channels, a_sample_rate, a_bits_per_sample, a_bsid;
-  dts_header_t dts_header;
+  mtx::dts::header_t dts_header;
 
   unsigned char *buffer;
   unsigned int buffer_usage, buffer_size;
@@ -182,7 +182,7 @@ struct mpeg_ps_track_t {
     delete multiple_timecodes_packet_extension;
   }
 };
-typedef std::shared_ptr<mpeg_ps_track_t> mpeg_ps_track_ptr;
+using mpeg_ps_track_ptr = std::shared_ptr<mpeg_ps_track_t>;
 
 inline bool
 operator <(mpeg_ps_track_ptr const &a,
