@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -22,18 +22,14 @@
 #include "common/codec.h"
 #include "common/endian.h"
 #include "common/dts.h"
+#include "common/hevc.h"
 #include "common/mm_io.h"
 #include "common/mpeg4_p10.h"
 #include "common/truehd.h"
 #include "input/packet_converter.h"
-#include "merge/pr_generic.h"
+#include "merge/generic_reader.h"
 #include "mpegparser/M2VParser.h"
 
-enum mpeg_ts_input_type_e {
-  INPUT_PROBE = 0,
-  INPUT_READ  = 1,
-};
-
 enum mpeg_ts_pid_type_e {
   PAT_TYPE      = 0,
   PMT_TYPE      = 1,
@@ -61,6 +57,7 @@ enum mpeg_ts_stream_type_e {
   ISO_14496_PART2_VIDEO     = 0x10, // ISO/IEC 14496-2 Visual (MPEG-4)
   ISO_14496_PART3_AUDIO     = 0x11, // ISO/IEC 14496-3 Audio with LATM transport syntax
   ISO_14496_PART10_VIDEO    = 0x1b, // ISO/IEC 14496-10 Video (MPEG-4 part 10/AVC, aka H.264)
+  ISO_23008_PART2_VIDEO     = 0x24, // ISO/IEC 14496-10 Video (MPEG-H part 2/HEVC, aka H.265)
   STREAM_AUDIO_PCM          = 0x80, // PCM
   STREAM_AUDIO_AC3          = 0x81, // Audio AC3 (A52)
   STREAM_AUDIO_DTS          = 0x82, // Audio DTS
@@ -68,6 +65,8 @@ enum mpeg_ts_stream_type_e {
   STREAM_AUDIO_AC3_PLUS     = 0x84, // Audio AC3 - Dolby Digital Plus (EAC3)
   STREAM_AUDIO_DTS_HD       = 0x85, // Audio DTS HD
   STREAM_AUDIO_DTS_HD_MA    = 0x86, // Audio DTS HD Master Audio
+  STREAM_AUDIO_AC3_PLUS2    = 0xa1, // Audio AC3 - Dolby Digital Plus (EAC3); secondary stream
+  STREAM_AUDIO_DTS_HD2      = 0xa2, // Audio DTS HD Express; secondary stream
   STREAM_VIDEO_VC1          = 0xEA, // Video VC-1
   STREAM_SUBTITLES_HDMV_PGS = 0x90, // HDMV PGS subtitles
 };
@@ -264,6 +263,9 @@ struct PACKED_STRUCTURE mpeg_ts_pes_header_t {
 
 class mpeg_ts_reader_c;
 
+class mpeg_ts_track_c;
+using mpeg_ts_track_ptr = std::shared_ptr<mpeg_ts_track_c>;
+
 class mpeg_ts_track_c {
 public:
   mpeg_ts_reader_c &reader;
@@ -290,10 +292,11 @@ public:
 
   // audio related parameters
   int a_channels, a_sample_rate, a_bits_per_sample, a_bsid;
-  dts_header_t a_dts_header;
-  aac_header_c m_aac_header;
+  mtx::dts::header_t a_dts_header;
+  aac::frame_c m_aac_frame;
 
-  bool m_apply_dts_timecode_fix, m_use_dts, m_timecodes_wrapped;
+  bool m_apply_dts_timecode_fix, m_use_dts, m_timecodes_wrapped, m_truehd_found_truehd, m_truehd_found_ac3;
+  mpeg_ts_track_ptr m_coupled_track;
 
   // general track parameters
   std::string language;
@@ -301,6 +304,7 @@ public:
   // used for probing for stream types
   byte_buffer_cptr m_probe_data;
   mpeg4::p10::avc_es_parser_cptr m_avc_parser;
+  mtx::hevc::es_parser_cptr m_hevc_parser;
   truehd_parser_cptr m_truehd_parser;
   std::shared_ptr<M2VParser> m_m2v_parser;
 
@@ -309,6 +313,7 @@ public:
   packet_converter_cptr converter;
 
   bool m_debug_delivery, m_debug_timecode_wrapping;
+  debugging_option_c m_debug_headers;
 
   mpeg_ts_track_c(mpeg_ts_reader_c &p_reader)
     : reader(p_reader)
@@ -337,9 +342,12 @@ public:
     , m_apply_dts_timecode_fix(false)
     , m_use_dts(false)
     , m_timecodes_wrapped{false}
+    , m_truehd_found_truehd{}
+    , m_truehd_found_ac3{}
     , skip_packet_data_bytes{}
-    , m_debug_delivery(false)
+    , m_debug_delivery{}
     , m_debug_timecode_wrapping{}
+    , m_debug_headers{"mpeg_ts|mpeg_ts_headers"}
   {
   }
 
@@ -349,6 +357,7 @@ public:
 
   int new_stream_v_mpeg_1_2();
   int new_stream_v_avc();
+  int new_stream_v_hevc();
   int new_stream_v_vc1();
   int new_stream_a_mpeg();
   int new_stream_a_aac();
@@ -359,6 +368,7 @@ public:
 
   bool parse_ac3_pmt_descriptor(mpeg_ts_pmt_descriptor_t const &pmt_descriptor, mpeg_ts_pmt_pid_info_t const &pmt_pid_info);
   bool parse_dts_pmt_descriptor(mpeg_ts_pmt_descriptor_t const &pmt_descriptor, mpeg_ts_pmt_pid_info_t const &pmt_pid_info);
+  bool parse_registration_pmt_descriptor(mpeg_ts_pmt_descriptor_t const &pmt_descriptor, mpeg_ts_pmt_pid_info_t const &pmt_pid_info);
   bool parse_srt_pmt_descriptor(mpeg_ts_pmt_descriptor_t const &pmt_descriptor, mpeg_ts_pmt_pid_info_t const &pmt_pid_info);
   bool parse_vobsub_pmt_descriptor(mpeg_ts_pmt_descriptor_t const &pmt_descriptor, mpeg_ts_pmt_pid_info_t const &pmt_pid_info);
 
@@ -373,8 +383,6 @@ public:
   void parse_iso639_language_from(void const *buffer);
 };
 
-typedef std::shared_ptr<mpeg_ts_track_c> mpeg_ts_track_ptr;
-
 class mpeg_ts_reader_c: public generic_reader_c {
 protected:
   bool PAT_found, PMT_found;
@@ -382,7 +390,7 @@ protected:
   int es_to_process;
   timecode_c m_global_timecode_offset, m_stream_timecode;
 
-  mpeg_ts_input_type_e input_status; // can be INPUT_PROBE, INPUT_READ
+  bool m_probing;
   int track_buffer_ready;
 
   bool file_done, m_packet_sent_to_packetizer;
@@ -392,9 +400,10 @@ protected:
 
   std::vector<timecode_c> m_chapter_timecodes;
 
-  debugging_option_c m_dont_use_audio_pts, m_debug_resync, m_debug_pat_pmt, m_debug_aac, m_debug_timecode_wrapping, m_debug_clpi;
+  debugging_option_c m_dont_use_audio_pts, m_debug_resync, m_debug_pat_pmt, m_debug_headers, m_debug_packet, m_debug_aac, m_debug_timecode_wrapping, m_debug_clpi;
 
-  int m_detected_packet_size;
+  unsigned int m_detected_packet_size, m_num_pat_crc_errors, m_num_pmt_crc_errors;
+  bool m_validate_pat_crc, m_validate_pmt_crc;
 
 protected:
   static int potential_packet_sizes[];
@@ -432,7 +441,11 @@ private:
   int send_to_packetizer(mpeg_ts_track_ptr &track);
   void create_mpeg1_2_video_packetizer(mpeg_ts_track_ptr &track);
   void create_mpeg4_p10_es_video_packetizer(mpeg_ts_track_ptr &track);
+  void create_mpegh_p2_es_video_packetizer(mpeg_ts_track_ptr &track);
   void create_vc1_video_packetizer(mpeg_ts_track_ptr &track);
+  void create_aac_audio_packetizer(mpeg_ts_track_ptr const &track);
+  void create_ac3_audio_packetizer(mpeg_ts_track_ptr const &track);
+  void create_truehd_audio_packetizer(mpeg_ts_track_ptr const &track);
   void create_hdmv_pgs_subtitles_packetizer(mpeg_ts_track_ptr &track);
   void create_srt_subtitles_packetizer(mpeg_ts_track_ptr const &track);
 
@@ -443,6 +456,8 @@ private:
 
   bool resync(int64_t start_at);
 
+  uint32_t calculate_crc(void const *buffer, size_t size) const;
+
   friend class mpeg_ts_track_c;
 };
 
