@@ -1,9 +1,13 @@
 #include "common/common_pch.h"
 
 #include <QLibraryInfo>
+#include <QLocalServer>
+#include <QLocalSocket>
+#include <QLockFile>
 
 #include <boost/optional.hpp>
 
+#include "common/command_line.h"
 #include "common/extern_data.h"
 #include "common/fs_sys_helpers.h"
 #include "common/iso639.h"
@@ -13,6 +17,7 @@
 #include "common/version.h"
 #include "mkvtoolnix-gui/app.h"
 #include "mkvtoolnix-gui/main_window/main_window.h"
+#include "mkvtoolnix-gui/util/util.h"
 #include "mkvtoolnix-gui/util/settings.h"
 
 namespace mtx { namespace gui {
@@ -29,6 +34,7 @@ App::App(int &argc,
   : QApplication{argc, argv}
 {
   mtx_common_init("mkvtoolnix-gui", argv[0]);
+  version_info = get_version_info("mkvtoolnix-gui", vif_full);
 
   // The routines for handling unique numbers cannot cope with
   // multiple chapters being worked on at the same time as they safe
@@ -46,7 +52,9 @@ App::App(int &argc,
 
   Util::Settings::get().load();
 
-  QObject::connect(this, SIGNAL(aboutToQuit()), this, SLOT(saveSettings()));
+  setupInstanceCommunicator();
+
+  QObject::connect(this, &App::aboutToQuit, this, &App::saveSettings);
 
   initializeLocale();
 }
@@ -54,6 +62,34 @@ App::App(int &argc,
 App::~App() {
 }
 
+QString
+App::communicatorSocketName() {
+  return Q("MKVToolNix-GUI-Instance-Communicator");
+}
+
+void
+App::setupInstanceCommunicator() {
+  auto socketName   = communicatorSocketName();
+  auto lockFilePath = QDir{QDir::tempPath()}.filePath(Q("%1.lock").arg(socketName));
+  m_instanceLock    = std::make_unique<QLockFile>(lockFilePath);
+
+  m_instanceLock->setStaleLockTime(0);
+  if (!m_instanceLock->tryLock(0)) {
+    m_instanceLock.reset(nullptr);
+    return;
+  }
+
+  QLocalServer::removeServer(socketName);
+
+  m_instanceCommunicator = std::make_unique<QLocalServer>(this);
+
+  if (m_instanceCommunicator->listen(socketName))
+    connect(m_instanceCommunicator.get(), &QLocalServer::newConnection, this, &App::receiveInstanceCommunication);
+
+  else
+    m_instanceCommunicator.reset(nullptr);
+}
+
 void
 App::saveSettings()
   const {
@@ -258,4 +294,90 @@ App::initializeLocale(QString const &requestedLocale) {
   retranslateUi();
 }
 
+bool
+App::isOtherInstanceRunning()
+  const {
+  return !m_instanceLock;
+}
+
+void
+App::sendArgumentsToRunningInstance() {
+  auto args = m_cliParser->rebuildCommandLine();
+  if (args.isEmpty())
+    return;
+
+  auto block = QByteArray{};
+  QDataStream out{&block, QIODevice::WriteOnly};
+
+  out.setVersion(QDataStream::Qt_5_0);
+  out << args;
+
+  auto socket = std::make_unique<QLocalSocket>(this);
+  socket->connectToServer(communicatorSocketName());
+
+  if (socket->state() != QLocalSocket::ConnectedState)
+    return;
+
+  socket->write(block);
+  socket->flush();
+}
+
+bool
+App::parseCommandLineArguments(QStringList const &args) {
+  if (args.isEmpty())
+    return true;
+
+  m_cliParser.reset(new GuiCliParser{Util::toStdStringVector(args, 1)});
+  m_cliParser->run();
+
+  if (m_cliParser->exitAfterParsing())
+    return false;
+
+  if (!isOtherInstanceRunning())
+    return true;
+
+  sendArgumentsToRunningInstance();
+  return false;
+}
+
+void
+App::handleCommandLineArgumentsLocally() {
+  if (!m_cliParser->m_configFiles.isEmpty())
+    emit openConfigFilesRequested(m_cliParser->m_configFiles);
+
+  if (!m_cliParser->m_addToMerge.isEmpty())
+    emit addingFilesToMergeRequested(m_cliParser->m_addToMerge);
+
+  if (!m_cliParser->m_editChapters.isEmpty())
+    emit editingChaptersRequested(m_cliParser->m_editChapters);
+
+  if (!m_cliParser->m_editHeaders.isEmpty())
+    emit editingHeadersRequested(m_cliParser->m_editHeaders);
+}
+
+void
+App::receiveInstanceCommunication() {
+  auto socket = m_instanceCommunicator->nextPendingConnection();
+  connect(socket, &QLocalSocket::disconnected, socket, &QLocalSocket::deleteLater);
+
+  if (!socket->waitForReadyRead(0))
+    return;
+
+  QDataStream in{socket};
+  in.setVersion(QDataStream::Qt_5_0);
+
+  auto args = QStringList{};
+  in >> args;
+  socket->disconnect();
+
+  m_cliParser.reset(new GuiCliParser{Util::toStdStringVector(args)});
+  m_cliParser->run();
+  handleCommandLineArgumentsLocally();
+}
+
+QString
+App::settingsBaseGroupName() {
+  return Q("MKVToolNix GUI Settings");
+}
+
 }}
