@@ -7,6 +7,11 @@
 #include <QStringList>
 #include <QTranslator>
 
+#include "mkvtoolnix-gui/gui_cli_parser.h"
+
+class QLocalServer;
+class QLockFile;
+
 namespace mtx { namespace gui {
 
 using Iso639Language     = std::pair<QString, QString>;
@@ -18,8 +23,19 @@ using CharacterSetList   = std::vector<QString>;
 class App : public QApplication {
   Q_OBJECT;
 
+protected:
+  enum class CliCommand {
+    OpenConfigFiles,
+    AddToMerge,
+    EditChapters,
+    EditHeaders,
+  };
+
 protected:
   std::unique_ptr<QTranslator> m_currentTranslator;
+  std::unique_ptr<GuiCliParser> m_cliParser;
+  std::unique_ptr<QLocalServer> m_instanceCommunicator;
+  std::unique_ptr<QLockFile> m_instanceLock;
 
 public:
   App(int &argc, char **argv);
@@ -28,9 +44,24 @@ public:
   void retranslateUi();
   void initializeLocale(QString const &requestedLocale = QString{});
 
+  bool parseCommandLineArguments(QStringList const &args);
+  void handleCommandLineArgumentsLocally();
+
+  bool isOtherInstanceRunning() const;
+  void sendArgumentsToRunningInstance();
+
+signals:
+  void addingFilesToMergeRequested(QStringList const &fileNames);
+  void editingChaptersRequested(QStringList const &fileNames);
+  void editingHeadersRequested(QStringList const &fileNames);
+  void openConfigFilesRequested(QStringList const &fileNames);
 
 public slots:
   void saveSettings() const;
+  void receiveInstanceCommunication();
+
+protected:
+  void setupInstanceCommunicator();
 
 public:
   static App *instance();
@@ -50,6 +81,9 @@ public:
   static void initializeCharacterSets();
 
   static bool isInstalled();
+
+  static QString communicatorSocketName();
+  static QString settingsBaseGroupName();
 };
 
 }}
