@@ -10,16 +10,20 @@
 
 #include "common/bitvalue.h"
 #include "common/chapters/chapters.h"
+#include "common/construct.h"
 #include "common/ebml.h"
 #include "common/mm_io_x.h"
+#include "common/mpls.h"
 #include "common/qt.h"
 #include "common/segmentinfo.h"
 #include "common/segment_tracks.h"
 #include "common/strings/formatting.h"
 #include "common/strings/parsing.h"
+#include "common/translation.h"
 #include "common/xml/ebml_chapters_converter.h"
 #include "mkvtoolnix-gui/app.h"
 #include "mkvtoolnix-gui/forms/chapter_editor/tab.h"
+#include "mkvtoolnix-gui/chapter_editor/generate_sub_chapters_parameters_dialog.h"
 #include "mkvtoolnix-gui/chapter_editor/name_model.h"
 #include "mkvtoolnix-gui/chapter_editor/mass_modification_dialog.h"
 #include "mkvtoolnix-gui/chapter_editor/tab.h"
@@ -50,6 +54,7 @@ Tab::Tab(QWidget *parent,
   , m_removeElementAction{new QAction{this}}
   , m_duplicateAction{new QAction{this}}
   , m_massModificationAction{new QAction{this}}
+  , m_generateSubChaptersAction{new QAction{this}}
 {
   // Setup UI controls.
   ui->setupUi(this);
@@ -96,6 +101,7 @@ Tab::setupUi() {
   connect(m_removeElementAction,           &QAction::triggered,                                                    this, &Tab::removeElement);
   connect(m_duplicateAction,               &QAction::triggered,                                                    this, &Tab::duplicateElement);
   connect(m_massModificationAction,        &QAction::triggered,                                                    this, &Tab::massModify);
+  connect(m_generateSubChaptersAction,     &QAction::triggered,                                                    this, &Tab::generateSubChapters);
 }
 
 void
@@ -128,6 +134,7 @@ Tab::retranslateUi() {
   m_removeElementAction->setText(QY("&Remove selected edition or chapter"));
   m_duplicateAction->setText(QY("D&uplicate selected edition or chapter"));
   m_massModificationAction->setText(QY("Additional &modifications"));
+  m_generateSubChaptersAction->setText(QY("&Generate sub-chapters"));
 
   m_chapterModel->retranslateUi();
   m_nameModel->retranslateUi();
@@ -192,7 +199,7 @@ Tab::resetData() {
   m_chapterModel->reset();
 }
 
-ChaptersPtr
+Tab::LoadResult
 Tab::loadFromMatroskaFile() {
   m_analyzer = std::make_unique<QtKaxAnalyzer>(this, m_fileName);
 
@@ -215,10 +222,10 @@ Tab::loadFromMatroskaFile() {
     emit removeThisTab();
   }
 
-  return std::static_pointer_cast<KaxChapters>(chapters);
+  return { std::static_pointer_cast<KaxChapters>(chapters), true };
 }
 
-ChaptersPtr
+Tab::LoadResult
 Tab::loadFromChapterFile() {
   auto isSimpleFormat = false;
   auto chapters       = ChaptersPtr{};
@@ -243,23 +250,84 @@ Tab::loadFromChapterFile() {
     emit removeThisTab();
 
   } else if (isSimpleFormat) {
-    Util::MessageBox::warning(this, QY("Simple chapter file format"), QY("The file you tried to open (%1) is a simple chapter file format. This can only be read but not written. "
-                                                                         "You will have to save the file to a Matroska or an XML chapter file.").arg(m_fileName));
     m_fileName.clear();
     emit titleChanged();
   }
 
+  return { chapters, !isSimpleFormat };
+}
+
+ChaptersPtr
+Tab::timecodesToChapters(std::vector<timecode_c> const &timecodes)
+  const {
+  auto &cfg     = Util::Settings::get();
+  auto chapters = ChaptersPtr{ static_cast<KaxChapters *>(mtx::construct::cons<KaxChapters>(mtx::construct::cons<KaxEditionEntry>())) };
+  auto &edition = GetChild<KaxEditionEntry>(*chapters);
+  auto idx      = 0;
+
+  for (auto const &timecode : timecodes) {
+    auto nameTemplate = QString{ cfg.m_chapterNameTemplate };
+    auto name         = to_wide(nameTemplate.replace(Q("<NUM>"), QString::number(++idx)));
+    auto atom         = mtx::construct::cons<KaxChapterAtom>(new KaxChapterTimeStart, timecode.to_ns(),
+                                                             mtx::construct::cons<KaxChapterDisplay>(new KaxChapterString,   name,
+                                                                                                     new KaxChapterLanguage, to_utf8(cfg.m_defaultChapterLanguage)));
+    if (!cfg.m_defaultChapterCountry.isEmpty())
+      GetChild<KaxChapterCountry>(GetChild<KaxChapterDisplay>(atom)).SetValue(to_utf8(cfg.m_defaultChapterCountry));
+
+    edition.PushElement(*atom);
+  }
+
   return chapters;
 }
 
+Tab::LoadResult
+Tab::loadFromMplsFile() {
+  auto chapters = ChaptersPtr{};
+  auto error    = QString{};
+
+  try {
+    auto in     = mm_file_io_c{to_utf8(m_fileName)};
+    auto parser = mpls::parser_c{};
+
+    parser.enable_dropping_last_entry_if_at_end(Util::Settings::get().m_dropLastChapterFromBlurayPlaylist);
+
+    if (parser.parse(&in))
+      chapters = timecodesToChapters(parser.get_chapters());
+
+  } catch (mtx::mm_io::exception &ex) {
+    error = Q(ex.what());
+
+  } catch (mtx::mpls::exception &ex) {
+    error = Q(ex.what());
+
+  }
+
+  if (!chapters) {
+    auto message = QY("The file you tried to open (%1) is recognized as neither a valid Matroska nor a valid chapter file.").arg(m_fileName);
+    if (!error.isEmpty())
+      message = Q("%1 %2").arg(message).arg(QY("Error message from the parser: %1").arg(error));
+
+    Util::MessageBox::critical(this, QY("File parsing failed"), message);
+    emit removeThisTab();
+
+  } else {
+    m_fileName.clear();
+    emit titleChanged();
+  }
+
+  return { chapters, false };
+}
+
 void
 Tab::load() {
   resetData();
 
-  m_savedState  = currentState();
-  auto chapters = kax_analyzer_c::probe(to_utf8(m_fileName)) ? loadFromMatroskaFile() : loadFromChapterFile();
+  m_savedState = currentState();
+  auto result  = kax_analyzer_c::probe(to_utf8(m_fileName)) ? loadFromMatroskaFile()
+               : m_fileName.toLower().endsWith(Q(".mpls"))  ? loadFromMplsFile()
+               :                                              loadFromChapterFile();
 
-  if (!chapters)
+  if (!result.first)
     return;
 
   if (!m_fileName.isEmpty())
@@ -267,8 +335,10 @@ Tab::load() {
 
   disconnect(m_chapterModel, &QStandardItemModel::rowsInserted, this, &Tab::expandInsertedElements);
 
-  m_chapterModel->populate(*chapters);
-  m_savedState = currentState();
+  m_chapterModel->populate(*result.first);
+
+  if (result.second)
+    m_savedState = currentState();
 
   expandAll();
   resizeChapterColumnsToContents();
@@ -304,10 +374,10 @@ Tab::saveAsImpl(bool requireNewFileName,
   m_savedState = currentState();
 
   if (newFileName != m_fileName) {
-    m_fileName                     = newFileName;
+    m_fileName             = newFileName;
 
-    auto &settings                 = Util::Settings::get();
-    settings.m_lastMatroskaFileDir = QFileInfo{newFileName}.path();
+    auto &settings         = Util::Settings::get();
+    settings.m_lastOpenDir = QFileInfo{newFileName}.path();
     settings.save();
 
     updateFileNameDisplay();
@@ -326,7 +396,7 @@ void
 Tab::saveAsXmlImpl(bool requireNewFileName) {
   saveAsImpl(requireNewFileName, [this](bool doRequireNewFileName, QString &newFileName) -> bool {
     if (doRequireNewFileName) {
-      auto defaultFilePath = !m_fileName.isEmpty() ? QFileInfo{m_fileName}.path() : Util::Settings::get().m_lastMatroskaFileDir.path();
+      auto defaultFilePath = !m_fileName.isEmpty() ? QFileInfo{m_fileName}.path() : Util::Settings::get().m_lastOpenDir.path();
       newFileName          = QFileDialog::getSaveFileName(this, QY("Save chapters as XML"), defaultFilePath, QY("XML chapter files") + Q(" (*.xml);;") + QY("All files") + Q(" (*)"));
 
       if (newFileName.isEmpty())
@@ -363,7 +433,7 @@ Tab::saveToMatroskaImpl(bool requireNewFileName) {
       doRequireNewFileName = true;
 
     if (doRequireNewFileName) {
-      auto defaultFilePath = !m_fileName.isEmpty() ? QFileInfo{m_fileName}.path() : Util::Settings::get().m_lastMatroskaFileDir.path();
+      auto defaultFilePath = !m_fileName.isEmpty() ? QFileInfo{m_fileName}.path() : Util::Settings::get().m_lastOpenDir.path();
       newFileName          = QFileDialog::getOpenFileName(this, QY("Save chapters to Matroska file"), defaultFilePath, QY("Matroska files") + Q(" (*.mkv *.mka *.mks *.mk3d);;") + QY("All files") + Q(" (*)"));
 
       if (newFileName.isEmpty())
@@ -795,17 +865,24 @@ Tab::addEdition(bool before) {
 }
 
 ChapterPtr
-Tab::createEmptyChapter(int64_t startTime) {
+Tab::createEmptyChapter(int64_t startTime,
+                        int chapterNumber,
+                        boost::optional<QString> const &nameTemplate,
+                        boost::optional<QString> const &language,
+                        boost::optional<QString> const &country) {
   auto &cfg     = Util::Settings::get();
   auto chapter  = std::make_shared<KaxChapterAtom>();
   auto &display = GetChild<KaxChapterDisplay>(*chapter);
+  auto name     = QString{ nameTemplate ? *nameTemplate : cfg.m_chapterNameTemplate };
+
+  name.replace(Q("<NUM>"), QString::number(chapterNumber));
 
   GetChild<KaxChapterUID>(*chapter).SetValue(0);
   GetChild<KaxChapterTimeStart>(*chapter).SetValue(startTime);
-  GetChild<KaxChapterString>(display).SetValueUTF8(Y("<unnamed>"));
-  GetChild<KaxChapterLanguage>(display).SetValue(to_utf8(cfg.m_defaultChapterLanguage));
-  if (!cfg.m_defaultChapterCountry.isEmpty())
-    GetChild<KaxChapterCountry>(display).SetValue(to_utf8(cfg.m_defaultChapterCountry));
+  GetChild<KaxChapterString>(display).SetValue(to_wide(name));
+  GetChild<KaxChapterLanguage>(display).SetValue(to_utf8(language ? *language : cfg.m_defaultChapterLanguage));
+  if ((country && !country->isEmpty()) || !cfg.m_defaultChapterCountry.isEmpty())
+    GetChild<KaxChapterCountry>(display).SetValue(to_utf8((country && !country->isEmpty()) ? *country : cfg.m_defaultChapterCountry));
 
   return chapter;
 }
@@ -827,8 +904,8 @@ Tab::addChapter(bool before) {
     return;
 
   // TODO: Tab::addChapter: start time
-  auto chapter = createEmptyChapter(0);
   auto row     = selectedIdx.row() + (before ? 0 : 1);
+  auto chapter = createEmptyChapter(0, row + 1);
 
   m_chapterModel->insertChapter(row, chapter, selectedIdx.parent());
 
@@ -842,7 +919,9 @@ Tab::addSubChapter() {
     return;
 
   // TODO: Tab::addSubChapter: start time
-  auto chapter = createEmptyChapter(0);
+  auto selectedItem = m_chapterModel->itemFromIndex(selectedIdx);
+  auto chapter      = createEmptyChapter(0, (selectedItem ? selectedItem->rowCount() : 0) + 1);
+
   m_chapterModel->appendChapter(chapter, selectedIdx);
   expandCollapseAll(true, selectedIdx);
 
@@ -1044,6 +1123,54 @@ Tab::duplicateElement() {
   emit numberOfEntriesChanged();
 }
 
+void
+Tab::generateSubChapters() {
+  auto selectedIdx = Util::selectedRowIdx(ui->elements);
+  if (!selectedIdx.isValid())
+    return;
+
+  if (!copyControlsToStorage())
+    return;
+
+  auto selectedItem    = m_chapterModel->itemFromIndex(selectedIdx);
+  auto selectedChapter = m_chapterModel->chapterFromItem(selectedItem);
+  auto maxEndTimecode  = selectedChapter ? FindChildValue<KaxChapterTimeStart>(*selectedChapter, 0ull) : 0ull;
+  auto numRows         = selectedItem->rowCount();
+
+  for (auto row = 0; row < numRows; ++row) {
+    auto chapter = m_chapterModel->chapterFromItem(selectedItem->child(row));
+    if (chapter)
+      maxEndTimecode = std::max(maxEndTimecode, std::max(FindChildValue<KaxChapterTimeStart>(*chapter, 0ull), FindChildValue<KaxChapterTimeEnd>(*chapter, 0ull)));
+  }
+
+  GenerateSubChaptersParametersDialog dlg{this, numRows + 1, maxEndTimecode};
+  if (!dlg.exec())
+    return;
+
+  auto toCreate      = dlg.numberOfEntries();
+  auto chapterNumber = dlg.firstChapterNumber();
+  auto timecode      = dlg.startTimecode();
+  auto duration      = dlg.durationInNs();
+  auto nameTemplate  = dlg.nameTemplate();
+  auto language      = dlg.language();
+  auto country       = dlg.country();
+
+  while (toCreate > 0) {
+    auto chapter = createEmptyChapter(timecode, chapterNumber, nameTemplate, language, country);
+    timecode    += duration;
+
+    ++chapterNumber;
+    --toCreate;
+
+    m_chapterModel->appendChapter(chapter, selectedIdx);
+  }
+
+  expandCollapseAll(true, selectedIdx);
+  resizeNameColumnsToContents();
+
+  emit numberOfEntriesChanged();
+}
+
 void
 Tab::expandCollapseAll(bool expand,
                        QModelIndex const &parentIdx) {
@@ -1083,6 +1210,7 @@ Tab::showChapterContextMenu(QPoint const &pos) {
   m_addChapterBeforeAction->setEnabled(chapterSelected);
   m_addChapterAfterAction->setEnabled(chapterSelected);
   m_addSubChapterAction->setEnabled(hasSelection);
+  m_generateSubChaptersAction->setEnabled(hasSelection);
   m_removeElementAction->setEnabled(hasSelection);
   m_duplicateAction->setEnabled(hasSelection);
   m_expandAllAction->setEnabled(hasEntries);
@@ -1096,6 +1224,7 @@ Tab::showChapterContextMenu(QPoint const &pos) {
   menu.addAction(m_addChapterBeforeAction);
   menu.addAction(m_addChapterAfterAction);
   menu.addAction(m_addSubChapterAction);
+  menu.addAction(m_generateSubChaptersAction);
   menu.addSeparator();
   menu.addAction(m_duplicateAction);
   menu.addSeparator();
