@@ -47,18 +47,20 @@ void
 Tool::setupActions() {
   auto mwUi = MainWindow::getUi();
 
-  connect(mwUi->actionChapterEditorNew,            &QAction::triggered,         this, &Tool::newFile);
-  connect(mwUi->actionChapterEditorOpen,           &QAction::triggered,         this, &Tool::selectFileToOpen);
-  connect(mwUi->actionChapterEditorSave,           &QAction::triggered,         this, &Tool::save);
-  connect(mwUi->actionChapterEditorSaveAsXml,      &QAction::triggered,         this, &Tool::saveAsXml);
-  connect(mwUi->actionChapterEditorSaveToMatroska, &QAction::triggered,         this, &Tool::saveToMatroska);
-  connect(mwUi->actionChapterEditorReload,         &QAction::triggered,         this, &Tool::reload);
-  connect(mwUi->actionChapterEditorClose,          &QAction::triggered,         this, &Tool::closeCurrentTab);
+  connect(mwUi->actionChapterEditorNew,            &QAction::triggered,            this, &Tool::newFile);
+  connect(mwUi->actionChapterEditorOpen,           &QAction::triggered,            this, &Tool::selectFileToOpen);
+  connect(mwUi->actionChapterEditorSave,           &QAction::triggered,            this, &Tool::save);
+  connect(mwUi->actionChapterEditorSaveAsXml,      &QAction::triggered,            this, &Tool::saveAsXml);
+  connect(mwUi->actionChapterEditorSaveToMatroska, &QAction::triggered,            this, &Tool::saveToMatroska);
+  connect(mwUi->actionChapterEditorReload,         &QAction::triggered,            this, &Tool::reload);
+  connect(mwUi->actionChapterEditorClose,          &QAction::triggered,            this, &Tool::closeCurrentTab);
 
-  connect(ui->newFileButton,                       &QPushButton::clicked,       this, &Tool::newFile);
-  connect(ui->openFileButton,                      &QPushButton::clicked,       this, &Tool::selectFileToOpen);
+  connect(ui->newFileButton,                       &QPushButton::clicked,          this, &Tool::newFile);
+  connect(ui->openFileButton,                      &QPushButton::clicked,          this, &Tool::selectFileToOpen);
 
-  connect(ui->editors,                             &QTabWidget::currentChanged, this, &Tool::enableMenuActions);
+  connect(ui->editors,                             &QTabWidget::currentChanged,    this, &Tool::enableMenuActions);
+
+  connect(App::instance(),                         &App::editingChaptersRequested, this, &Tool::openFilesFromCommandLine);
 }
 
 void
@@ -127,13 +129,13 @@ Tool::dragEnterEvent(QDragEnterEvent *event) {
 void
 Tool::dropEvent(QDropEvent *event) {
   if (m_filesDDHandler.handle(event, true))
-    filesDropped(m_filesDDHandler.fileNames());
+    openFiles(m_filesDDHandler.fileNames());
 }
 
 void
 Tool::openFile(QString const &fileName) {
   auto &settings = Util::Settings::get();
-  settings.m_lastMatroskaFileDir = QFileInfo{fileName}.path();
+  settings.m_lastOpenDir = QFileInfo{fileName}.path();
   settings.save();
 
   appendTab(new Tab{this, fileName})
@@ -141,16 +143,23 @@ Tool::openFile(QString const &fileName) {
 }
 
 void
-Tool::filesDropped(QStringList const &fileNames) {
+Tool::openFiles(QStringList const &fileNames) {
   for (auto const &fileName : fileNames)
     openFile(fileName);
 }
 
+void
+Tool::openFilesFromCommandLine(QStringList const &fileNames) {
+  MainWindow::get()->switchToTool(this);
+  openFiles(fileNames);
+}
+
 void
 Tool::selectFileToOpen() {
-  auto fileNames = QFileDialog::getOpenFileNames(this, QY("Open files in chapter editor"), Util::Settings::get().m_lastMatroskaFileDir.path(),
-                                                 QY("Supported file types")           + Q(" (*.mkv *.mka *.mks *.mk3d *.txt *.xml);;") +
+  auto fileNames = QFileDialog::getOpenFileNames(this, QY("Open files in chapter editor"), Util::Settings::get().m_lastOpenDir.path(),
+                                                 QY("Supported file types")           + Q(" (*.mpls *.mkv *.mka *.mks *.mk3d *.txt *.xml);;") +
                                                  QY("Matroska files")                 + Q(" (*.mkv *.mka *.mks *.mk3d);;") +
+                                                 QY("Blu-ray playlist files")         + Q(" (*.mpls);;") +
                                                  QY("XML chapter files")              + Q(" (*.xml);;") +
                                                  QY("Simple OGM-style chapter files") + Q(" (*.txt);;") +
                                                  QY("All files")                      + Q(" (*)"));
