@@ -46,6 +46,8 @@ public slots:
   virtual void closeSendingTab();
   virtual bool closeAllTabs();
   virtual void reload();
+  virtual void openFiles(QStringList const &fileNames);
+  virtual void openFilesFromCommandLine(QStringList const &fileNames);
 
 protected:
   virtual void openFile(QString const &fileName);
