@@ -30,7 +30,11 @@ PreferencesDialog::PreferencesDialog(QWidget *parent)
   ui->cbGuiWarnBeforeAbortingJobs->setChecked(m_cfg.m_warnBeforeAbortingJobs);
   setupOnlineCheck();
   setupInterfaceLanguage();
-  setupJobsJobOutput();
+
+  ui->cbGuiUseDefaultJobDescription->setChecked(m_cfg.m_useDefaultJobDescription);
+  ui->cbGuiShowOutputOfAllJobs->setChecked(m_cfg.m_showOutputOfAllJobs);
+  setupJobRemovalPolicy();
+
   setupCommonLanguages();
   setupCommonCountries();
   setupCommonCharacterSets();
@@ -39,6 +43,9 @@ PreferencesDialog::PreferencesDialog(QWidget *parent)
   ui->cbMAutoSetFileTitle->setChecked(m_cfg.m_autoSetFileTitle);
   ui->cbMSetAudioDelayFromFileName->setChecked(m_cfg.m_setAudioDelayFromFileName);
   ui->cbMDisableCompressionForAllTrackTypes->setChecked(m_cfg.m_disableCompressionForAllTrackTypes);
+  ui->cbMAlwaysAddDroppedFiles->setChecked(m_cfg.m_mergeAlwaysAddDroppedFiles);
+  ui->cbMAlwaysShowOutputFileControls->setChecked(m_cfg.m_mergeAlwaysShowOutputFileControls);
+  ui->cbMClearMergeSettings->setCurrentIndex(static_cast<int>(m_cfg.m_clearMergeSettings));
   Util::setupLanguageComboBox(*ui->cbMDefaultTrackLanguage, m_cfg.m_defaultTrackLanguage);
   Util::setupCharacterSetComboBox(*ui->cbMDefaultSubtitleCharset, m_cfg.m_defaultSubtitleCharset);
   ui->leMDefaultAdditionalCommandLineOptions->setText(m_cfg.m_defaultAdditionalMergeOptions);
@@ -49,6 +56,8 @@ PreferencesDialog::PreferencesDialog(QWidget *parent)
   setupEnableMuxingTracksByLanguage();
 
   // Chapter editor page
+  ui->leCENameTemplate->setText(m_cfg.m_chapterNameTemplate);
+  ui->cbCEDropLastFromBlurayPlaylist->setChecked(m_cfg.m_dropLastChapterFromBlurayPlaylist);
   Util::setupLanguageComboBox(*ui->cbCEDefaultLanguage, m_cfg.m_defaultChapterLanguage);
   Util::setupCountryComboBox(*ui->cbCEDefaultCountry, m_cfg.m_defaultChapterCountry, true, QY("– no selection by default –"));
 
@@ -91,13 +100,24 @@ PreferencesDialog::setupToolTips() {
   Util::setToolTip(ui->cbGuiWarnBeforeOverwriting, QY("If enabled the program will ask for confirmation before overwriting files and jobs."));
   ui->cbGuiWarnBeforeOverwriting->setEnabled(false);
 
+  Util::setToolTip(ui->cbGuiUseDefaultJobDescription, QY("If disabled the GUI will let you enter a description for a job when adding it to the queue."));
+  Util::setToolTip(ui->cbGuiShowOutputOfAllJobs,      QY("If enabled the first tab in the »watch jobs« tool will not be cleared when a new job starts."));
+
   Util::setToolTip(ui->cbGuiRemoveJobs,
                    Q("%1 %2")
                    .arg(QY("Normally completed jobs stay in the queue even over restarts until the user clears them out manually."))
                    .arg(QY("You can opt for having them removed automatically under certain conditions.")));
 
+  Util::setToolTip(ui->leCENameTemplate,
+                   Q("%1 %2")
+                   .arg(QY("This template will be used for new chapter entries."))
+                   .arg(QY("The string '<NUM>' will be replaced by the chapter number.")));
   Util::setToolTip(ui->cbCEDefaultLanguage, QY("This is the language that newly added chapter names get assigned automatically."));
   Util::setToolTip(ui->cbCEDefaultCountry, QY("This is the country that newly added chapter names get assigned automatically."));
+  Util::setToolTip(ui->cbCEDropLastFromBlurayPlaylist,
+                   Q("%1 %2")
+                   .arg(QY("Blu-ray discs often contain a chapter entry very close to the end of the movie."))
+                   .arg(QY("If enabled the last entry will be skipped when loading chapters from such playlists in the chapter editor if it is located within five seconds of the end of the movie.")));
 
   // Merge page
   Util::setToolTip(ui->cbMAutoSetFileTitle,
@@ -116,6 +136,20 @@ PreferencesDialog::setupToolTips() {
                    .arg(QY("Normally mkvmerge will apply additional lossless compression for subtitle tracks for certain codecs."))
                    .arg(QY("Checking this option causes the GUI to set that compression to »none« by default for all track types when adding files.")));
 
+  Util::setToolTip(ui->cbMAlwaysAddDroppedFiles, QY("If disabled the GUI will ask whether you want to add the dropped files, append them or add them as additional parts."));
+  Util::setToolTip(ui->cbMAlwaysShowOutputFileControls,
+                   Q("%1 %2")
+                   .arg(QY("If enabled the output file name controls will always be visible no matter which tab is currently shown."))
+                   .arg(QY("Otherwise they're shown on the 'output' tab.")));
+
+  Util::setToolTip(ui->cbMClearMergeSettings,
+                   Q("<p>%1</p><ol><li>%2 %3</li><li>%4 %5</li></ol>")
+                   .arg(QY("The GUI can help you start your next merge settings after having started a job or having added a one to the job queue."))
+                   .arg(QY("With »create new settings« a new set of merge settings will be added."))
+                   .arg(QY("The current merge settings will be closed."))
+                   .arg(QY("With »remove input files« all input files will be removed."))
+                   .arg(QY("Most of the other settings on the output tab will be kept intact, though.")));
+
   Util::setToolTip(ui->cbMDefaultTrackLanguage,
                    Q("<p>%1 %2</p><p>%3</p>")
                    .arg(QY("Certain file formats have a 'language' property for their tracks."))
@@ -175,7 +209,7 @@ PreferencesDialog::setupConnections() {
   connect(ui->cbGuiRemoveJobs,                            &QCheckBox::toggled,         ui->cbGuiJobRemovalPolicy,            &QComboBox::setEnabled);
   connect(ui->cbMAutoSetOutputFileName,                   &QCheckBox::toggled,         this,                                 &PreferencesDialog::enableOutputFileNameControls);
   connect(ui->rbMAutoSetSameDirectory,                    &QRadioButton::toggled,      this,                                 &PreferencesDialog::enableOutputFileNameControls);
-  connect(ui->rbMAutoSetParentDirectory,                  &QRadioButton::toggled,      this,                                 &PreferencesDialog::enableOutputFileNameControls);
+  connect(ui->rbMAutoSetRelativeDirectory,                &QRadioButton::toggled,      this,                                 &PreferencesDialog::enableOutputFileNameControls);
   connect(ui->rbMAutoSetPreviousDirectory,                &QRadioButton::toggled,      this,                                 &PreferencesDialog::enableOutputFileNameControls);
   connect(ui->rbMAutoSetFixedDirectory,                   &QRadioButton::toggled,      this,                                 &PreferencesDialog::enableOutputFileNameControls);
   connect(ui->pbMBrowseAutoSetFixedDirectory,             &QPushButton::clicked,       this,                                 &PreferencesDialog::browseFixedOutputDirectory);
@@ -217,7 +251,7 @@ PreferencesDialog::setupInterfaceLanguage() {
 }
 
 void
-PreferencesDialog::setupJobsJobOutput() {
+PreferencesDialog::setupJobRemovalPolicy() {
   auto doRemove = Util::Settings::JobRemovalPolicy::Never != m_cfg.m_jobRemovalPolicy;
   auto idx      = std::max(static_cast<int>(m_cfg.m_jobRemovalPolicy), 1) - 1;
 
@@ -273,13 +307,14 @@ PreferencesDialog::setupPlaylistScanningPolicy() {
 void
 PreferencesDialog::setupOutputFileNamePolicy() {
   auto isChecked = Util::Settings::DontSetOutputFileName != m_cfg.m_outputFileNamePolicy;
-  auto rbToCheck = Util::Settings::ToPreviousDirectory      == m_cfg.m_outputFileNamePolicy ? ui->rbMAutoSetPreviousDirectory
-                 : Util::Settings::ToFixedDirectory         == m_cfg.m_outputFileNamePolicy ? ui->rbMAutoSetFixedDirectory
-                 : Util::Settings::ToParentOfFirstInputFile == m_cfg.m_outputFileNamePolicy ? ui->rbMAutoSetParentDirectory
-                 :                                                                            ui->rbMAutoSetSameDirectory;
+  auto rbToCheck = Util::Settings::ToPreviousDirectory        == m_cfg.m_outputFileNamePolicy ? ui->rbMAutoSetPreviousDirectory
+                 : Util::Settings::ToFixedDirectory           == m_cfg.m_outputFileNamePolicy ? ui->rbMAutoSetFixedDirectory
+                 : Util::Settings::ToRelativeOfFirstInputFile == m_cfg.m_outputFileNamePolicy ? ui->rbMAutoSetRelativeDirectory
+                 :                                                                              ui->rbMAutoSetSameDirectory;
 
   ui->cbMAutoSetOutputFileName->setChecked(isChecked);
   rbToCheck->setChecked(true);
+  ui->leMAutoSetRelativeDirectory->setText(m_cfg.m_relativeOutputDir.path());
   ui->leMAutoSetFixedDirectory->setText(m_cfg.m_fixedOutputDir.path());
   ui->cbMUniqueOutputFileNames->setChecked(m_cfg.m_uniqueOutputFileNames);
 
@@ -304,36 +339,44 @@ PreferencesDialog::setupEnableMuxingTracksByLanguage() {
 void
 PreferencesDialog::save() {
   // GUI page:
-  m_cfg.m_uiLocale                      = ui->cbGuiInterfaceLanguage->currentData().toString();
-  m_cfg.m_checkForUpdates               = ui->cbGuiCheckForUpdates->isChecked();
-  m_cfg.m_disableAnimations             = ui->cbGuiDisableAnimations->isChecked();
-  m_cfg.m_warnBeforeClosingModifiedTabs = ui->cbGuiWarnBeforeClosingModifiedTabs->isChecked();
-  m_cfg.m_warnBeforeAbortingJobs        = ui->cbGuiWarnBeforeAbortingJobs->isChecked();
-  auto idx                              = !ui->cbGuiRemoveJobs->isChecked() ? 0 : ui->cbGuiJobRemovalPolicy->currentIndex() + 1;
-  m_cfg.m_jobRemovalPolicy              = static_cast<Util::Settings::JobRemovalPolicy>(idx);
+  m_cfg.m_uiLocale                           = ui->cbGuiInterfaceLanguage->currentData().toString();
+  m_cfg.m_checkForUpdates                    = ui->cbGuiCheckForUpdates->isChecked();
+  m_cfg.m_disableAnimations                  = ui->cbGuiDisableAnimations->isChecked();
+  m_cfg.m_warnBeforeClosingModifiedTabs      = ui->cbGuiWarnBeforeClosingModifiedTabs->isChecked();
+  m_cfg.m_warnBeforeAbortingJobs             = ui->cbGuiWarnBeforeAbortingJobs->isChecked();
+  m_cfg.m_useDefaultJobDescription           = ui->cbGuiUseDefaultJobDescription->isChecked();
+  m_cfg.m_showOutputOfAllJobs                = ui->cbGuiShowOutputOfAllJobs->isChecked();
+  auto idx                                   = !ui->cbGuiRemoveJobs->isChecked() ? 0 : ui->cbGuiJobRemovalPolicy->currentIndex() + 1;
+  m_cfg.m_jobRemovalPolicy                   = static_cast<Util::Settings::JobRemovalPolicy>(idx);
 
-  m_cfg.m_defaultChapterLanguage        = ui->cbCEDefaultLanguage->currentData().toString();
-  m_cfg.m_defaultChapterCountry         = ui->cbCEDefaultCountry->currentData().toString();
+  m_cfg.m_chapterNameTemplate                = ui->leCENameTemplate->text();
+  m_cfg.m_defaultChapterLanguage             = ui->cbCEDefaultLanguage->currentData().toString();
+  m_cfg.m_defaultChapterCountry              = ui->cbCEDefaultCountry->currentData().toString();
+  m_cfg.m_dropLastChapterFromBlurayPlaylist  = ui->cbCEDropLastFromBlurayPlaylist->isChecked();
 
   // Merge page:
-  m_cfg.m_autoSetFileTitle              = ui->cbMAutoSetFileTitle->isChecked();
-  m_cfg.m_setAudioDelayFromFileName     = ui->cbMSetAudioDelayFromFileName->isChecked();
+  m_cfg.m_autoSetFileTitle                   = ui->cbMAutoSetFileTitle->isChecked();
+  m_cfg.m_setAudioDelayFromFileName          = ui->cbMSetAudioDelayFromFileName->isChecked();
   m_cfg.m_disableCompressionForAllTrackTypes = ui->cbMDisableCompressionForAllTrackTypes->isChecked();
-  m_cfg.m_defaultTrackLanguage          = ui->cbMDefaultTrackLanguage->currentData().toString();
-  m_cfg.m_defaultSubtitleCharset        = ui->cbMDefaultSubtitleCharset->currentData().toString();
-  m_cfg.m_priority                      = static_cast<Util::Settings::ProcessPriority>(ui->cbMProcessPriority->currentData().toInt());
-  m_cfg.m_defaultAdditionalMergeOptions = ui->leMDefaultAdditionalCommandLineOptions->text();
+  m_cfg.m_mergeAlwaysAddDroppedFiles         = ui->cbMAlwaysAddDroppedFiles->isChecked();
+  m_cfg.m_mergeAlwaysShowOutputFileControls  = ui->cbMAlwaysShowOutputFileControls->isChecked();
+  m_cfg.m_clearMergeSettings                 = static_cast<Util::Settings::ClearMergeSettingsAction>(ui->cbMClearMergeSettings->currentIndex());
+  m_cfg.m_defaultTrackLanguage               = ui->cbMDefaultTrackLanguage->currentData().toString();
+  m_cfg.m_defaultSubtitleCharset             = ui->cbMDefaultSubtitleCharset->currentData().toString();
+  m_cfg.m_priority                           = static_cast<Util::Settings::ProcessPriority>(ui->cbMProcessPriority->currentData().toInt());
+  m_cfg.m_defaultAdditionalMergeOptions      = ui->leMDefaultAdditionalCommandLineOptions->text();
 
-  m_cfg.m_scanForPlaylistsPolicy        = static_cast<Util::Settings::ScanForPlaylistsPolicy>(ui->cbMScanPlaylistsPolicy->currentIndex());
-  m_cfg.m_minimumPlaylistDuration       = ui->sbMMinPlaylistDuration->value();
+  m_cfg.m_scanForPlaylistsPolicy             = static_cast<Util::Settings::ScanForPlaylistsPolicy>(ui->cbMScanPlaylistsPolicy->currentIndex());
+  m_cfg.m_minimumPlaylistDuration            = ui->sbMMinPlaylistDuration->value();
 
-  m_cfg.m_outputFileNamePolicy          = !ui->cbMAutoSetOutputFileName->isChecked()   ? Util::Settings::DontSetOutputFileName
-                                        : ui->rbMAutoSetParentDirectory->isChecked()   ? Util::Settings::ToParentOfFirstInputFile
-                                        : ui->rbMAutoSetFixedDirectory->isChecked()    ? Util::Settings::ToFixedDirectory
-                                        : ui->rbMAutoSetPreviousDirectory->isChecked() ? Util::Settings::ToPreviousDirectory
-                                        :                                                Util::Settings::ToSameAsFirstInputFile;
-  m_cfg.m_fixedOutputDir                = ui->leMAutoSetFixedDirectory->text();
-  m_cfg.m_uniqueOutputFileNames         = ui->cbMUniqueOutputFileNames->isChecked();
+  m_cfg.m_outputFileNamePolicy               = !ui->cbMAutoSetOutputFileName->isChecked()   ? Util::Settings::DontSetOutputFileName
+                                             : ui->rbMAutoSetRelativeDirectory->isChecked() ? Util::Settings::ToRelativeOfFirstInputFile
+                                             : ui->rbMAutoSetFixedDirectory->isChecked()    ? Util::Settings::ToFixedDirectory
+                                             : ui->rbMAutoSetPreviousDirectory->isChecked() ? Util::Settings::ToPreviousDirectory
+                                             :                                                Util::Settings::ToSameAsFirstInputFile;
+  m_cfg.m_relativeOutputDir                  = ui->leMAutoSetRelativeDirectory->text();
+  m_cfg.m_fixedOutputDir                     = ui->leMAutoSetFixedDirectory->text();
+  m_cfg.m_uniqueOutputFileNames              = ui->cbMUniqueOutputFileNames->isChecked();
 
   m_cfg.m_enableMuxingTracksByLanguage       = ui->cbMEnableMuxingTracksByLanguage->isChecked();
   m_cfg.m_enableMuxingAllVideoTracks         = ui->cbMEnableMuxingAllVideoTracks->isChecked();
@@ -342,20 +385,22 @@ PreferencesDialog::save() {
   m_cfg.m_enableMuxingTracksByTheseLanguages = ui->tbMEnableMuxingTracksByLanguage->selectedItemValues();
 
   // Often used selections page:
-  m_cfg.m_oftenUsedLanguages            = ui->tbOftenUsedLanguages->selectedItemValues();
-  m_cfg.m_oftenUsedCountries            = ui->tbOftenUsedCountries->selectedItemValues();
-  m_cfg.m_oftenUsedCharacterSets        = ui->tbOftenUsedCharacterSets->selectedItemValues();
+  m_cfg.m_oftenUsedLanguages                 = ui->tbOftenUsedLanguages->selectedItemValues();
+  m_cfg.m_oftenUsedCountries                 = ui->tbOftenUsedCountries->selectedItemValues();
+  m_cfg.m_oftenUsedCharacterSets             = ui->tbOftenUsedCharacterSets->selectedItemValues();
 
   m_cfg.save();
 }
 
 void
 PreferencesDialog::enableOutputFileNameControls() {
-  bool isChecked     = ui->cbMAutoSetOutputFileName->isChecked();
-  bool fixedSelected = ui->rbMAutoSetFixedDirectory->isChecked();
+  bool isChecked        = ui->cbMAutoSetOutputFileName->isChecked();
+  bool relativeSelected = ui->rbMAutoSetRelativeDirectory->isChecked();
+  bool fixedSelected    = ui->rbMAutoSetFixedDirectory->isChecked();
 
-  Util::enableWidgets(QList<QWidget *>{} << ui->rbMAutoSetSameDirectory  << ui->rbMAutoSetParentDirectory << ui->rbMAutoSetPreviousDirectory << ui->rbMAutoSetFixedDirectory << ui->cbMUniqueOutputFileNames, isChecked);
+  Util::enableWidgets(QList<QWidget *>{} << ui->rbMAutoSetSameDirectory  << ui->rbMAutoSetPreviousDirectory << ui->rbMAutoSetRelativeDirectory << ui->rbMAutoSetFixedDirectory << ui->cbMUniqueOutputFileNames, isChecked);
   Util::enableWidgets(QList<QWidget *>{} << ui->leMAutoSetFixedDirectory << ui->pbMBrowseAutoSetFixedDirectory, isChecked && fixedSelected);
+  ui->leMAutoSetRelativeDirectory->setEnabled(isChecked && relativeSelected);
 }
 
 void
