@@ -7,6 +7,7 @@
 #include <QFileInfo>
 #include <QList>
 #include <QMessageBox>
+#include <QRegularExpression>
 #include <QString>
 #include <QTimer>
 
@@ -151,6 +152,7 @@ Tab::setupInputControls() {
 
   connect(m_filesModel,                 &SourceFileModel::rowsInserted,             this,          &Tab::onFileRowsInserted);
   connect(m_tracksModel,                &TrackModel::rowsInserted,                  this,          &Tab::onTrackRowsInserted);
+  connect(m_tracksModel,                &TrackModel::itemChanged,                   this,          &Tab::onTrackItemChanged);
 
   onTrackSelectionChanged();
   enableTracksActions();
@@ -459,6 +461,33 @@ Tab::onTrackNameEdited(QString newValue) {
   withSelectedTracks([&](Track *track) { track->m_name = newValue; }, true);
 }
 
+void
+Tab::onTrackItemChanged(QStandardItem *item) {
+  if (!item)
+    return;
+
+  auto idx = m_tracksModel->indexFromItem(item);
+  if (idx.column())
+    return;
+
+  auto track = m_tracksModel->fromIndex(idx);
+  if (!track)
+    return;
+
+  auto newMuxThis = item->checkState() == Qt::Checked;
+  if (newMuxThis == track->m_muxThis)
+    return;
+
+  track->m_muxThis = newMuxThis;
+  m_tracksModel->trackUpdated(track);
+
+  auto selected = selectedTracks();
+  if ((1 == selected.count()) && selected.contains(track))
+    Util::setComboBoxIndexIf(ui->muxThis, [newMuxThis](QString const &, QVariant const &data) { return data.isValid() && (data.toBool() == newMuxThis); });
+
+  setOutputFileNameMaybe(ui->output->text());
+}
+
 void
 Tab::onMuxThisChanged(int selected) {
   auto data = ui->muxThis->itemData(selected);
@@ -467,6 +496,8 @@ Tab::onMuxThisChanged(int selected) {
   auto muxThis = data.toBool();
 
   withSelectedTracks([&](Track *track) { track->m_muxThis = muxThis; });
+
+  setOutputFileNameMaybe(ui->output->text());
 }
 
 void
@@ -507,7 +538,11 @@ Tab::onDefaultTrackFlagChanged(int newValue) {
     return;
   newValue = data.toInt();
 
-  withSelectedTracks([&](Track *track) { track->m_defaultTrackFlag = newValue; }, true);
+  withSelectedTracks([&](Track *track) {
+    track->m_defaultTrackFlag = newValue;
+    if (1 == newValue)
+      ensureOneDefaultFlagOnly(track);
+  }, true);
 }
 
 void
@@ -729,10 +764,21 @@ void
 Tab::setDefaultsFromSettingsForAddedFiles(QList<SourceFilePtr> const &files) {
   auto &cfg = Util::Settings::get();
 
+  auto defaultFlagSet = QHash<Track::Type, bool>{};
+  for (auto const &track : m_config.m_tracks)
+    if (track->m_defaultTrackFlag == 1)
+      defaultFlagSet[track->m_type] = true;
+
   for (auto const &file : files)
-    for (auto const &track : file->m_tracks)
+    for (auto const &track : file->m_tracks) {
       if (cfg.m_disableCompressionForAllTrackTypes)
         track->m_compression = Track::CompNone;
+
+      if (track->m_defaultTrackFlagWasSet && !defaultFlagSet[track->m_type]) {
+        track->m_defaultTrackFlag     = 1;
+        defaultFlagSet[track->m_type] = true;
+      }
+    }
 }
 
 QStringList
@@ -773,6 +819,11 @@ Tab::onRemoveFiles() {
   m_filesModel->removeFiles(selectedFiles);
 
   reinitFilesTracksControls();
+
+  if (!m_filesModel->rowCount()) {
+    clearDestinationMaybe();
+    clearTitleMaybe();
+  }
 }
 
 void
@@ -786,6 +837,8 @@ Tab::onRemoveAllFiles() {
   m_config.m_tracks.clear();
 
   reinitFilesTracksControls();
+  clearDestinationMaybe();
+  clearTitleMaybe();
 }
 
 void
@@ -947,17 +1000,13 @@ Tab::setOutputFileNameMaybe(QString const &fileName) {
   else if (Util::Settings::ToSameAsFirstInputFile == policy)
     outputDir = srcFileName.absoluteDir();
 
-  else if (Util::Settings::ToParentOfFirstInputFile == policy) {
-    outputDir = srcFileName.absoluteDir();
-    outputDir.cdUp();
+  else if (Util::Settings::ToRelativeOfFirstInputFile == policy)
+    outputDir = QDir{ srcFileName.absoluteDir().path() + Q("/") + settings.m_relativeOutputDir.path() };
 
-  } else
+  else
     Q_ASSERT_X(false, "setOutputFileNameMaybe", "Untested output file name policy");
 
-  if (!outputDir.exists())
-    outputDir = srcFileName.absoluteDir();
-
-  auto baseName = srcFileName.completeBaseName();
+  auto baseName = srcFileName.completeBaseName().replace(QRegularExpression{" \\(\\d+\\)$"}, Q(""));
   auto idx      = 0;
 
   while (true) {
@@ -977,7 +1026,7 @@ Tab::setOutputFileNameMaybe(QString const &fileName) {
 
 void
 Tab::addOrAppendDroppedFiles(QStringList const &fileNames) {
-  if (m_config.m_files.isEmpty()) {
+  if (m_config.m_files.isEmpty() || Util::Settings::get().m_mergeAlwaysAddDroppedFiles) {
     addOrAppendFiles(false, fileNames, {});
     return;
   }
@@ -1058,4 +1107,17 @@ Tab::enableDisableAllTracks(bool enable) {
   ui->muxThis->setCurrentIndex(base + (enable ? 0 : 1));
 }
 
+void
+Tab::ensureOneDefaultFlagOnly(Track *thisOneHasIt) {
+  auto selection = selectedTracks();
+  for (auto const &track : m_config.m_tracks)
+    if (   (track->m_defaultTrackFlag == 1)
+        && (track->m_type             == thisOneHasIt->m_type)
+        && (track                     != thisOneHasIt)) {
+      track->m_defaultTrackFlag = 0;
+      if ((selection.count() == 1) && (selection[0] == track))
+        ui->defaultTrackFlag->setCurrentIndex(0);
+    }
+}
+
 }}}
