@@ -2,6 +2,7 @@
 
 #include "common/at_scope_exit.h"
 #include "common/strings/editing.h"
+#include "mkvtoolnix-gui/app.h"
 #include "mkvtoolnix-gui/merge/attachment.h"
 #include "mkvtoolnix-gui/merge/mux_config.h"
 #include "mkvtoolnix-gui/merge/source_file.h"
@@ -43,6 +44,11 @@ fixMappings(SourceFile *oldFile,
 
   Q_ASSERT(!!oldFile && !!newFile);
 
+  if (oldFile->m_appendedTo) {
+    newFile->m_appendedTo = fileMap[oldFile->m_appendedTo];
+    Q_ASSERT(!!newFile->m_appendedTo);
+  }
+
   for (auto idx = 0, end = oldFile->m_tracks.size(); idx < end; ++idx) {
     auto oldTrack = oldFile->m_tracks[idx].get();
     auto newTrack = trackMap[oldTrack];
@@ -72,7 +78,6 @@ MuxConfig::MuxConfig(QString const &fileName)
   , m_splitMaxFiles{0}
   , m_linkFiles{false}
   , m_webmMode{false}
-  , m_titleWasPresent{}
 {
   auto &settings      = Util::Settings::get();
   m_additionalOptions = settings.m_defaultAdditionalMergeOptions;
@@ -166,7 +171,15 @@ MuxConfig::load(QSettings &settings) {
   reset();
 
   // Check supported config file version
-  if (settings.value("version", std::numeric_limits<int>::max()).toInt() > MTXCFG_VERSION)
+  if (settings.childGroups().contains(App::settingsBaseGroupName())) {
+    settings.beginGroup(App::settingsBaseGroupName());
+    if (   (settings.value("version", std::numeric_limits<int>::max()).toInt() > MTXCFG_VERSION)
+        || (settings.value("type").toString() != settingsType()))
+      throw InvalidSettingsX{};
+    settings.endGroup();
+
+  } else if (settings.value("version", std::numeric_limits<int>::max()).toInt() > MTXCFG_VERSION)
+    // Config files written until 8.0.0 didn't use that group.
     throw InvalidSettingsX{};
 
   settings.beginGroup("input");
@@ -231,7 +244,10 @@ MuxConfig::saveProperties(QSettings &settings,
 void
 MuxConfig::save(QSettings &settings)
   const {
+  settings.beginGroup(App::settingsBaseGroupName());
   settings.setValue("version", MTXCFG_VERSION);
+  settings.setValue("type",    settingsType());
+  settings.endGroup();
 
   settings.beginGroup("input");
   saveSettingsGroup("files",       m_files,       settings);
@@ -403,7 +419,7 @@ MuxConfig::buildMkvmergeOptions()
       options << arg << value;
   };
 
-  add(Q("--title"), m_title, m_titleWasPresent || !m_title.isEmpty());
+  add(Q("--title"), m_title, !m_title.isEmpty() || hasSourceFileWithTitle());
   add(Q("--segment-uid"), m_segmentUIDs);
   add(Q("--previous-segment-uid"), m_previousSegmentUID);
   add(Q("--next-segment-uid"), m_nextSegmentUID);
@@ -429,6 +445,16 @@ MuxConfig::buildMkvmergeOptions()
   return options;
 }
 
+bool
+MuxConfig::hasSourceFileWithTitle()
+  const {
+  for (auto const &sourceFile : m_files)
+    if (sourceFile->m_properties.contains(Q("title")) && !sourceFile->m_properties[Q("title")].isEmpty())
+      return true;
+
+  return false;
+}
+
 void
 MuxConfig::debugDumpFileList()
   const {
@@ -469,4 +495,9 @@ MuxConfig::debugDumpSpecificTrackList(QList<Track *> const &tracks) {
   }
 }
 
+QString
+MuxConfig::settingsType() {
+  return Q("MuxConfig");
+}
+
 }}}
