@@ -71,7 +71,7 @@ public:
   QString m_segmentUIDs, m_previousSegmentUID, m_nextSegmentUID, m_chapters, m_chapterLanguage, m_chapterCharacterSet, m_chapterCueNameFormat, m_additionalOptions;
   SplitMode m_splitMode;
   unsigned int m_splitMaxFiles;
-  bool m_linkFiles, m_webmMode, m_titleWasPresent;
+  bool m_linkFiles, m_webmMode;
 
 public:
   MuxConfig(QString const &fileName = QString{""});
@@ -88,6 +88,8 @@ public:
   QString toString() const;
   QStringList buildMkvmergeOptions() const;
 
+  virtual bool hasSourceFileWithTitle() const;
+
   virtual void debugDumpFileList() const;
   virtual void debugDumpTrackList() const;
 
@@ -101,6 +103,7 @@ public:
   static void saveProperties(QSettings &settings, QHash<QString, QString> const &properties);
   static void loadProperties(QSettings &settings, QHash<QString, QString> &properties);
   static void debugDumpSpecificTrackList(QList<Track *> const &tracks);
+  static QString settingsType();
 };
 
 template<typename T>
