@@ -7,6 +7,7 @@
 #include "mkvtoolnix-gui/main_window/main_window.h"
 #include "mkvtoolnix-gui/merge/command_line_dialog.h"
 #include "mkvtoolnix-gui/merge/tab.h"
+#include "mkvtoolnix-gui/merge/tool.h"
 #include "mkvtoolnix-gui/forms/main_window/main_window.h"
 #include "mkvtoolnix-gui/forms/merge/tab.h"
 #include "mkvtoolnix-gui/util/message_box.h"
@@ -203,7 +204,9 @@ Tab::getSaveFileName(QString const &title,
   fullFilter += QY("All files") + Q(" (*)");
 
   auto &settings = Util::Settings::get();
-  auto dir       = lineEdit->text().isEmpty() ? settings.m_lastOutputDir.path() : lineEdit->text();
+  auto dir       = !lineEdit->text().isEmpty()                                                               ? lineEdit->text()
+                 : !settings.m_lastOutputDir.path().isEmpty() && (settings.m_lastOutputDir.path() != Q(".")) ? settings.m_lastOutputDir.path()
+                 :                                                                                             settings.m_lastOpenDir.path();
   auto fileName  = QFileDialog::getSaveFileName(this, title, dir, fullFilter);
   if (fileName.isEmpty())
     return fileName;
@@ -267,6 +270,8 @@ Tab::isReadyForMerging() {
 
 void
 Tab::addToJobQueue(bool startNow) {
+  updateConfigFromControlValues();
+
   if (!isReadyForMerging())
     return;
 
@@ -276,17 +281,19 @@ Tab::addToJobQueue(bool startNow) {
   job->m_description = job->displayableDescription();
 
   if (!startNow) {
-    auto newDescription = QString{};
+    if (!Util::Settings::get().m_useDefaultJobDescription) {
+      auto newDescription = QString{};
 
-    while (newDescription.isEmpty()) {
-      bool ok = false;
-      newDescription = QInputDialog::getText(this, QY("Enter job description"), QY("Please enter the new job's description."), QLineEdit::Normal, job->m_description, &ok);
-      if (!ok)
-        return;
+      while (newDescription.isEmpty()) {
+        bool ok = false;
+        newDescription = QInputDialog::getText(this, QY("Enter job description"), QY("Please enter the new job's description."), QLineEdit::Normal, job->m_description, &ok);
+        if (!ok)
+          return;
+      }
+
+      job->m_description = newDescription;
     }
 
-    job->m_description = newDescription;
-
     MainWindow::get()->showIconMovingToTool(Q("task-delegate.png"), *MainWindow::jobTool());
 
   } else
@@ -295,17 +302,34 @@ Tab::addToJobQueue(bool startNow) {
   MainWindow::jobTool()->addJob(std::static_pointer_cast<Jobs::Job>(job));
 
   m_savedState = currentState();
+
+  handleClearingMergeSettings();
+}
+
+void
+Tab::handleClearingMergeSettings() {
+  auto action = Util::Settings::get().m_clearMergeSettings;
+  if (Util::Settings::ClearMergeSettingsAction::None == action)
+    return;
+
+  if (Util::Settings::ClearMergeSettingsAction::RemoveInputFiles == action) {
+    onRemoveAllFiles();
+    return;
+  }
+
+  // Util::Settings::ClearMergeSettingsAction::NewSettings
+  MainWindow::mergeTool()->newConfig();
+  emit removeThisTab();
 }
 
 QString
-Tab::currentState()
-  const {
+Tab::currentState() {
+  updateConfigFromControlValues();
   return m_config.toString();
 }
 
 bool
-Tab::hasBeenModified()
-  const {
+Tab::hasBeenModified() {
   return currentState() != m_savedState;
 }
 
