@@ -55,7 +55,7 @@ public:
   explicit Tab(QWidget *parent);
   ~Tab();
 
-  virtual bool hasBeenModified() const;
+  virtual bool hasBeenModified();
 
   virtual QString const &fileName() const;
   virtual QString title() const;
@@ -89,6 +89,7 @@ public slots:
   virtual void onTrackSelectionChanged();
 
   virtual void onTrackNameEdited(QString newValue);
+  virtual void onTrackItemChanged(QStandardItem *item);
   virtual void onMuxThisChanged(int selected);
   virtual void onTrackLanguageChanged(int newValue);
   virtual void onDefaultTrackFlagChanged(int newValue);
@@ -127,7 +128,12 @@ public slots:
   virtual void addFilesToBeAddedOrAppendedDelayed(QStringList const &fileNames);
 
   // Output tab:
+  virtual void setupOutputFileControls();
   virtual void setDestination(QString const &newValue);
+  virtual void clearDestination();
+  virtual void clearDestinationMaybe();
+  virtual void clearTitle();
+  virtual void clearTitleMaybe();
 
   virtual void onTitleEdited(QString newValue);
   virtual void onBrowseOutput();
@@ -164,6 +170,7 @@ public slots:
   virtual void resizeAttachmentsColumnsToContents() const;
 
   virtual void retranslateUi();
+  virtual void handleClearingMergeSettings();
 
 protected:
   virtual void setupAttachmentsControls();
@@ -199,6 +206,9 @@ protected:
   virtual QString getOpenFileName(QString const &title, QString const &filter, QLineEdit *lineEdit);
   virtual QString getSaveFileName(QString const &title, QString const &filter, QLineEdit *lineEdit);
 
+  virtual void moveOutputFileNameToGlobal();
+  virtual void moveOutputFileNameToOutputTab();
+
   virtual QModelIndex selectedSourceFile() const;
   virtual QList<SourceFile *> selectedSourceFiles() const;
   virtual QList<Track *> selectedTracks() const;
@@ -215,7 +225,9 @@ protected:
 
   virtual void enableDisableAllTracks(bool enable);
 
-  virtual QString currentState() const;
+  virtual void ensureOneDefaultFlagOnly(Track *thisOneHasIt);
+
+  virtual QString currentState();
 };
 
 }}}
