@@ -43,12 +43,22 @@ public slots:
   virtual void closeSendingTab();
   virtual bool closeAllTabs();
 
+  virtual void saveConfig();
+  virtual void saveConfigAs();
+  virtual void saveOptionFile();
+  virtual void startMuxing();
+  virtual void addToJobQueue();
+  virtual void showCommandLine();
+
   virtual void toolShown() override;
   virtual void tabTitleChanged();
-  virtual void reconnectMenuActions();
 
   virtual void filesDropped(QStringList const &fileNames);
 
+  virtual void addMultipleFiles(QStringList const &fileNames);
+  virtual void addMultipleFilesFromCommandLine(QStringList const &fileNames);
+  virtual void openMultipleConfigFilesFromCommandLine(QStringList const &fileNames);
+
 protected:
   Tab *appendTab(Tab *tab);
   virtual Tab *currentTab();
