@@ -94,6 +94,8 @@ TrackModel::setItemsFromTrack(QList<QStandardItem *> items,
   items[6]->setText(-1 == track->m_id ? Q("") : QString::number(track->m_id));
 
   items[0]->setData(QVariant::fromValue(reinterpret_cast<qulonglong>(track)), Util::TrackRole);
+  items[0]->setCheckable(true);
+  items[0]->setCheckState(track->m_muxThis ? Qt::Checked : Qt::Unchecked);
   items[1]->setIcon(  track->isAudio()      ? m_audioIcon
                     : track->isVideo()      ? m_videoIcon
                     : track->isSubtitles()  ? m_subtitleIcon
@@ -116,20 +118,43 @@ TrackModel::fromIndex(QModelIndex const &idx)
                                    .value<qulonglong>());
 }
 
+QModelIndex
+TrackModel::indexFromTrack(Track *track) {
+  for (auto topRow = 0, numTopRows = rowCount(); topRow < numTopRows; ++topRow) {
+    auto topIdx = index(topRow, 0);
+    if (fromIndex(topIdx) == track)
+      return topIdx;
+
+    auto topItem = itemFromIndex(topIdx);
+    if (!topItem)
+      continue;
+
+    for (auto childRow = 0, numChildRows = topItem->rowCount(); childRow < numChildRows; ++childRow) {
+      auto childIdx = topIdx.child(childRow, 0);
+      if (fromIndex(childIdx) == track)
+        return childIdx;
+    }
+  }
+
+  return {};
+}
+
+QStandardItem *
+TrackModel::itemFromTrack(Track *track) {
+  return itemFromIndex(indexFromTrack(track));
+}
+
 void
 TrackModel::trackUpdated(Track *track) {
   Q_ASSERT(m_tracks);
 
-  auto topRow     = m_tracks->indexOf(track->isAppended() ? track->m_appendedTo : track);
-  auto parentItem = track->isAppended() ? item(topRow, 0)                                      : invisibleRootItem();
-  auto row        = track->isAppended() ? track->m_appendedTo->m_appendedTracks.indexOf(track) : topRow;
-
-  if ((-1 == topRow) || (-1 == row) || !parentItem)
+  auto idx = indexFromTrack(track);
+  if (!idx.isValid())
     return;
 
   auto items = QList<QStandardItem *>{};
   for (auto column = 0, numColumns = columnCount(); column < numColumns; ++column)
-    items << parentItem->child(row, column);
+    items << itemFromIndex(idx.sibling(idx.row(), column));
 
   setItemsFromTrack(items, track);
 }
@@ -159,6 +184,8 @@ TrackModel::appendTracks(SourceFile *fileToAppendTo,
   auto lastTrack = boost::accumulate(*m_tracks, static_cast<Track *>(nullptr), [](Track *accu, Track *t) { return t->isRegular() ? t : accu; });
   Q_ASSERT(!!lastTrack);
 
+  auto trackOffsets = QHash<Track::Type, int>{};
+
   for (auto &newTrack : tracks) {
     // Things like tags, chapters and attachments aren't appended to a
     // specific track. Instead they're appended to the top list.
@@ -167,9 +194,11 @@ TrackModel::appendTracks(SourceFile *fileToAppendTo,
       continue;
     }
 
-    newTrack->m_appendedTo = fileToAppendTo->findFirstTrackOfType(newTrack->m_type);
-    if (!newTrack->m_appendedTo)
+    newTrack->m_appendedTo = fileToAppendTo->findNthOrLastTrackOfType(newTrack->m_type, trackOffsets[newTrack->m_type]++);
+    if (!newTrack->m_appendedTo) {
       newTrack->m_appendedTo = lastTrack;
+      newTrack->m_muxThis    = false;
+    }
 
     auto row = m_tracks->indexOf(newTrack->m_appendedTo);
     Q_ASSERT(row != -1);
