@@ -3,6 +3,7 @@
 #include <QDragEnterEvent>
 #include <QDragMoveEvent>
 
+#include "common/list_utils.h"
 #include "mkvtoolnix-gui/util/basic_tree_view.h"
 
 namespace mtx { namespace gui { namespace Util {
@@ -30,6 +31,12 @@ BasicTreeView::dropInFirstColumnOnly(bool enable) {
   return *this;
 }
 
+BasicTreeView &
+BasicTreeView::enterActivatesAllSelected(bool enable) {
+  m_enterActivatesAllSelected = enable;
+  return *this;
+}
+
 void
 BasicTreeView::dragEnterEvent(QDragEnterEvent *event) {
   if (m_acceptDroppedFiles && m_filesDDHandler.handle(event, false))
@@ -61,4 +68,20 @@ BasicTreeView::dropEvent(QDropEvent *event) {
   QTreeView::dropEvent(event);
 }
 
+void
+BasicTreeView::keyPressEvent(QKeyEvent *event) {
+  if (   m_enterActivatesAllSelected
+      && (event->modifiers() == Qt::NoModifier)
+      && mtx::included_in(static_cast<Qt::Key>(event->key()), Qt::Key_Return, Qt::Key_Enter)) {
+    emit allSelectedActivated();
+    event->accept();
+
+  } else if (   (event->modifiers() == Qt::NoModifier)
+             && mtx::included_in(static_cast<Qt::Key>(event->key()), Qt::Key_Backspace, Qt::Key_Delete))
+    emit deletePressed();
+
+  else
+    QTreeView::keyPressEvent(event);
+}
+
 }}}
