@@ -48,7 +48,6 @@ Settings::load() {
   m_lastOpenDir                        = QDir{reg.value("lastOpenDir").toString()};
   m_lastOutputDir                      = QDir{reg.value("lastOutputDir").toString()};
   m_lastConfigDir                      = QDir{reg.value("lastConfigDir").toString()};
-  m_lastMatroskaFileDir                = QDir{reg.value("lastMatroskaFileDir").toString()};
 
   m_oftenUsedLanguages                 = reg.value("oftenUsedLanguages").toStringList();
   m_oftenUsedCountries                 = reg.value("oftenUsedCountries").toStringList();
@@ -59,10 +58,14 @@ Settings::load() {
 
   m_setAudioDelayFromFileName          = reg.value("setAudioDelayFromFileName", true).toBool();
   m_autoSetFileTitle                   = reg.value("autoSetFileTitle",          true).toBool();
+  m_clearMergeSettings                 = static_cast<ClearMergeSettingsAction>(reg.value("clearMergeSettings", static_cast<int>(ClearMergeSettingsAction::None)).toInt());
   m_disableCompressionForAllTrackTypes = reg.value("disableCompressionForAllTrackTypes", false).toBool();
+  m_mergeAlwaysAddDroppedFiles         = reg.value("mergeAlwaysAddDroppedFiles", true).toBool();
+  m_mergeAlwaysShowOutputFileControls  = reg.value("mergeAlwaysShowOutputFileControls", true).toBool();
 
   m_uniqueOutputFileNames              = reg.value("uniqueOutputFileNames",     true).toBool();
   m_outputFileNamePolicy               = static_cast<OutputFileNamePolicy>(reg.value("outputFileNamePolicy", static_cast<int>(ToSameAsFirstInputFile)).toInt());
+  m_relativeOutputDir                  = QDir{reg.value("relativeOutputDir").toString()};
   m_fixedOutputDir                     = QDir{reg.value("fixedOutputDir").toString()};
 
   m_enableMuxingTracksByLanguage       = reg.value("enableMuxingTracksByLanguage", false).toBool();
@@ -71,12 +74,17 @@ Settings::load() {
   m_enableMuxingAllSubtitleTracks      = reg.value("enableMuxingAllSubtitleTracks", false).toBool();
   m_enableMuxingTracksByTheseLanguages = reg.value("enableMuxingTracksByTheseLanguages").toStringList();
 
+  m_useDefaultJobDescription           = reg.value("useDefaultJobDescription", false).toBool();
+  m_showOutputOfAllJobs                = reg.value("showOutputOfAllJobs",      true).toBool();
   m_jobRemovalPolicy                   = static_cast<JobRemovalPolicy>(reg.value("jobRemovalPolicy", static_cast<int>(JobRemovalPolicy::Never)).toInt());
 
   m_disableAnimations                  = reg.value("disableAnimations", false).toBool();
   m_warnBeforeClosingModifiedTabs      = reg.value("warnBeforeClosingModifiedTabs", true).toBool();
   m_warnBeforeAbortingJobs             = reg.value("warnBeforeAbortingJobs", true).toBool();
 
+  m_chapterNameTemplate                = reg.value("chapterNameTemplate", QY("Chapter <NUM>")).toString();
+  m_dropLastChapterFromBlurayPlaylist  = reg.value("dropLastChapterFromBlurayPlaylist", true).toBool();
+
 #if defined(HAVE_LIBINTL_H)
   m_uiLocale                           = reg.value("uiLocale").toString();
 #endif
@@ -106,6 +114,11 @@ Settings::load() {
   if (m_oftenUsedCharacterSets.isEmpty())
     for (auto const &characterSet : g_popular_character_sets)
       m_oftenUsedCharacterSets << Q(characterSet);
+
+  if (ToParentOfFirstInputFile == m_outputFileNamePolicy) {
+    m_outputFileNamePolicy = ToRelativeOfFirstInputFile;
+    m_relativeOutputDir    = Q("..");
+  }
 }
 
 QString
@@ -125,7 +138,6 @@ Settings::save()
   reg.setValue("lastOpenDir",                        m_lastOpenDir.path());
   reg.setValue("lastOutputDir",                      m_lastOutputDir.path());
   reg.setValue("lastConfigDir",                      m_lastConfigDir.path());
-  reg.setValue("lastMatroskaFileDir",                m_lastMatroskaFileDir.path());
 
   reg.setValue("oftenUsedLanguages",                 m_oftenUsedLanguages);
   reg.setValue("oftenUsedCountries",                 m_oftenUsedCountries);
@@ -136,9 +148,13 @@ Settings::save()
 
   reg.setValue("setAudioDelayFromFileName",          m_setAudioDelayFromFileName);
   reg.setValue("autoSetFileTitle",                   m_autoSetFileTitle);
+  reg.setValue("clearMergeSettings",                 static_cast<int>(m_clearMergeSettings));
   reg.setValue("disableCompressionForAllTrackTypes", m_disableCompressionForAllTrackTypes);
+  reg.setValue("mergeAlwaysAddDroppedFiles",         m_mergeAlwaysAddDroppedFiles);
+  reg.setValue("mergeAlwaysShowOutputFileControls",  m_mergeAlwaysShowOutputFileControls);
 
   reg.setValue("outputFileNamePolicy",               static_cast<int>(m_outputFileNamePolicy));
+  reg.setValue("relativeOutputDir",                  m_relativeOutputDir.path());
   reg.setValue("fixedOutputDir",                     m_fixedOutputDir.path());
   reg.setValue("uniqueOutputFileNames",              m_uniqueOutputFileNames);
 
@@ -148,12 +164,17 @@ Settings::save()
   reg.setValue("enableMuxingAllSubtitleTracks",      m_enableMuxingAllSubtitleTracks);
   reg.setValue("enableMuxingTracksByTheseLanguages", m_enableMuxingTracksByTheseLanguages);
 
+  reg.setValue("useDefaultJobDescription",           m_useDefaultJobDescription);
+  reg.setValue("showOutputOfAllJobs",                m_showOutputOfAllJobs);
   reg.setValue("jobRemovalPolicy",                   static_cast<int>(m_jobRemovalPolicy));
 
   reg.setValue("disableAnimations",                  m_disableAnimations);
   reg.setValue("warnBeforeClosingModifiedTabs",      m_warnBeforeClosingModifiedTabs);
   reg.setValue("warnBeforeAbortingJobs",             m_warnBeforeAbortingJobs);
 
+  reg.setValue("chapterNameTemplate",                m_chapterNameTemplate);
+  reg.setValue("dropLastChapterFromBlurayPlaylist",  m_dropLastChapterFromBlurayPlaylist);
+
   reg.setValue("uiLocale",                           m_uiLocale);
 
   reg.beginGroup("updates");
