@@ -35,6 +35,7 @@ public:
     ToFixedDirectory,
     ToParentOfFirstInputFile,
     ToSameAsFirstInputFile,
+    ToRelativeOfFirstInputFile,
   };
 
   enum class JobRemovalPolicy {
@@ -44,20 +45,28 @@ public:
     Always,
   };
 
-  QString m_defaultTrackLanguage, m_defaultChapterLanguage, m_defaultChapterCountry, m_defaultSubtitleCharset, m_defaultAdditionalMergeOptions;
+  enum class ClearMergeSettingsAction {
+    None,
+    NewSettings,
+    RemoveInputFiles,
+  };
+
+  QString m_defaultTrackLanguage, m_chapterNameTemplate, m_defaultChapterLanguage, m_defaultChapterCountry, m_defaultSubtitleCharset, m_defaultAdditionalMergeOptions;
   QStringList m_oftenUsedLanguages, m_oftenUsedCountries, m_oftenUsedCharacterSets;
   ProcessPriority m_priority;
-  QDir m_lastOpenDir, m_lastOutputDir, m_lastConfigDir, m_lastMatroskaFileDir;
-  bool m_setAudioDelayFromFileName, m_autoSetFileTitle, m_disableCompressionForAllTrackTypes;
+  QDir m_lastOpenDir, m_lastOutputDir, m_lastConfigDir;
+  bool m_setAudioDelayFromFileName, m_autoSetFileTitle, m_disableCompressionForAllTrackTypes, m_mergeAlwaysAddDroppedFiles, m_mergeAlwaysShowOutputFileControls, m_dropLastChapterFromBlurayPlaylist;
+  ClearMergeSettingsAction m_clearMergeSettings;
 
   OutputFileNamePolicy m_outputFileNamePolicy;
-  QDir m_fixedOutputDir;
+  QDir m_relativeOutputDir, m_fixedOutputDir;
   bool m_uniqueOutputFileNames;
 
   ScanForPlaylistsPolicy m_scanForPlaylistsPolicy;
   unsigned int m_minimumPlaylistDuration;
 
   JobRemovalPolicy m_jobRemovalPolicy;
+  bool m_useDefaultJobDescription, m_showOutputOfAllJobs;
 
   bool m_checkForUpdates;
   QDateTime m_lastUpdateCheck;
