@@ -185,7 +185,22 @@ Tab::onLineRead(QString const &line,
 
 void
 Tab::setInitialDisplay(Jobs::Job const &job) {
-  m_fullOutput          = job.m_fullOutput;
+  if (isCurrentJobTab() && Util::Settings::get().m_showOutputOfAllJobs) {
+    auto outputOfJobLine = QY("--- Output of job '%1' started on %2 ---").arg(job.m_description).arg(Util::displayableDate(job.m_dateStarted));
+    m_fullOutput << outputOfJobLine << job.m_fullOutput;
+
+    ui->output  ->appendPlainText(outputOfJobLine);
+    ui->warnings->appendPlainText(QY("--- Warnings emitted by job '%1' started on %2 ---").arg(job.m_description).arg(Util::displayableDate(job.m_dateStarted)));
+    ui->errors  ->appendPlainText(QY("--- Errors emitted by job '%1' started on %2 ---").arg(job.m_description).arg(Util::displayableDate(job.m_dateStarted)));
+
+  } else {
+    m_fullOutput = job.m_fullOutput;
+
+    ui->output  ->setPlainText(!job.m_output.isEmpty()   ? Q("%1\n").arg(job.m_output.join("\n"))   : Q(""));
+    ui->warnings->setPlainText(!job.m_warnings.isEmpty() ? Q("%1\n").arg(job.m_warnings.join("\n")) : Q(""));
+    ui->errors  ->setPlainText(!job.m_errors.isEmpty()   ? Q("%1\n").arg(job.m_errors.join("\n"))   : Q(""));
+  }
+
   m_currentJobStatus    = job.m_status;
   m_currentJobProgress  = job.m_progress;
   m_currentJobStartTime = job.m_dateStarted;
@@ -195,10 +210,6 @@ Tab::setInitialDisplay(Jobs::Job const &job) {
   ui->status->setText(Jobs::Job::displayableStatus(job.m_status));
   ui->progressBar->setValue(job.m_progress);
 
-  ui->output  ->setPlainText(!job.m_output.isEmpty()   ? Q("%1\n").arg(job.m_output.join("\n"))   : Q(""));
-  ui->warnings->setPlainText(!job.m_warnings.isEmpty() ? Q("%1\n").arg(job.m_warnings.join("\n")) : Q(""));
-  ui->errors  ->setPlainText(!job.m_errors.isEmpty()   ? Q("%1\n").arg(job.m_errors.join("\n"))   : Q(""));
-
   ui->startedAt ->setText(job.m_dateStarted .isValid() ? Util::displayableDate(job.m_dateStarted)  : QY("not started yet"));
   ui->finishedAt->setText(job.m_dateFinished.isValid() ? Util::displayableDate(job.m_dateFinished) : QY("not finished yet"));
 
@@ -214,7 +225,7 @@ void
 Tab::onSaveOutput() {
   auto &cfg = Util::Settings::get();
 
-  auto fileName = QFileDialog::getSaveFileName(this, QY("Save job output"), cfg.m_lastConfigDir.path(), QY("Text files") + Q(" (*.txt);;") + QY("All files") + Q(" (*)"));
+  auto fileName = QFileDialog::getSaveFileName(this, QY("Save job output"), cfg.m_lastOpenDir.path(), QY("Text files") + Q(" (*.txt);;") + QY("All files") + Q(" (*)"));
   if (fileName.isEmpty())
     return;
 
@@ -224,7 +235,7 @@ Tab::onSaveOutput() {
     out.close();
   }
 
-  cfg.m_lastConfigDir = QFileInfo{fileName}.path();
+  cfg.m_lastOpenDir = QFileInfo{fileName}.path();
   cfg.save();
 }
 
@@ -240,6 +251,12 @@ Tab::isSaveOutputEnabled()
   return ui->saveOutputButton->isEnabled();
 }
 
+bool
+Tab::isCurrentJobTab()
+  const {
+  return this == MainWindow::get()->watchCurrentJobTab();
+}
+
 void
 Tab::acknowledgeWarningsAndErrors() {
   MainWindow::jobTool()->acknowledgeWarningsAndErrors(m_id);
